@@ -9,6 +9,6 @@ def match(command):
 
 def get_new_command(command):
     broken = command.script_parts[1]
-    fix = re.findall(r'Did you mean `yarn ([^`]*)`', command.stderr)[0]
+    fix = re.findall(r'Did you mean [`"](?:yarn )?([^`"]*)[`"]', command.stderr)[0]
 
     return replace_argument(command.script, broken, fix)
