@@ -1,6 +1,5 @@
 import os
 import pickle
-import pkg_resources
 import re
 import shelve
 import six
@@ -8,7 +7,7 @@ from contextlib import closing
 from decorator import decorator
 from difflib import get_close_matches
 from functools import wraps
-from warnings import warn
+from .logs import warn
 from .conf import settings
 from .system import Path
 
@@ -108,9 +107,7 @@ def get_all_executables():
             return fallback
 
     tf_alias = get_alias()
-    tf_entry_points = get_installation_info().get_entry_map()\
-                                             .get('console_scripts', {})\
-                                             .keys()
+    tf_entry_points = ['thefuck', 'fuck']
 
     bins = [exe.name.decode('utf8') if six.PY2 else exe.name
             for path in os.environ.get('PATH', '').split(':')
@@ -141,12 +138,17 @@ def eager(fn, *args, **kwargs):
 
 @eager
 def get_all_matched_commands(stderr, separator='Did you mean'):
+    if not isinstance(separator, list):
+        separator = [separator]
     should_yield = False
     for line in stderr.split('\n'):
-        if separator in line:
-            should_yield = True
-        elif should_yield and line:
-            yield line.strip()
+        for sep in separator:
+            if sep in line:
+                should_yield = True
+                break
+        else:
+            if should_yield and line:
+                yield line.strip()
 
 
 def replace_command(command, broken, matched):
@@ -250,6 +252,8 @@ cache.disabled = False
 
 
 def get_installation_info():
+    import pkg_resources
+
     return pkg_resources.require('thefuck')[0]
 
 
@@ -278,3 +282,18 @@ def get_valid_history_without_current(command):
     return [line for line in _not_corrected(history, tf_alias)
             if not line.startswith(tf_alias) and not line == command.script
             and line.split(' ')[0] in executables]
+
+
+def format_raw_script(raw_script):
+    """Creates single script from a list of script parts.
+
+    :type raw_script: [basestring]
+    :rtype: basestring
+
+    """
+    if six.PY2:
+        script = ' '.join(arg.decode('utf-8') for arg in raw_script)
+    else:
+        script = ' '.join(raw_script)
+
+    return script.strip()
